colour.models.dataset.don_rgb_4 Module — Colour 0.3.0 documentation

# colour.models.dataset.don_rgb_4 Module

## Don RGB 4 Colourspace

Defines the Don RGB 4 colourspace:

- `DON_RGB_4_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.hutchcolor.com/profiles/DonRGB4.zip (Last accessed 12 April 2014)

`colour.models.dataset.don_rgb_4.` `DON_RGB_4_PRIMARIES` = array([[ 0.69612069, 0.29956897], [ 0.21468298, 0.76529477], [ 0.12993763, 0.03534304]])

  Don RGB 4 colourspace primaries.

  DON_RGB_4_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.don_rgb_4.` `DON_RGB_4_WHITEPOINT` = (0.34567, 0.3585)

  Don RGB 4 colourspace whitepoint.

  DON_RGB_4_WHITEPOINT : tuple

`colour.models.dataset.don_rgb_4.` `DON_RGB_4_TO_XYZ_MATRIX` = array([[ 0.6462101 , 0.19297238, 0.12502951], [ 0.27809042, 0.68790156, 0.03400803], [ 0.0040013 , 0.01799742, 0.80318956]])

  Don RGB 4 colourspace to CIE XYZ colourspace matrix.

  DON_RGB_4_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.don_rgb_4.` `XYZ_TO_DON_RGB_4_MATRIX` = array([[ 1.75848724, -0.48667396, -0.25313075], [-0.71123914, 1.65214904, 0.04076192], [ 0.00717668, -0.03459594, 1.24538377]])

  CIE XYZ colourspace to Don RGB 4 colourspace matrix.

  XYZ_TO_DON_RGB_4_MATRIX : array_like, (3, 3)

`colour.models.dataset.don_rgb_4.` `DON_RGB_4_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Don RGB 4 colourspace.

  DON_RGB_4_TRANSFER_FUNCTION : object

`colour.models.dataset.don_rgb_4.` `DON_RGB_4_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Don RGB 4 colourspace to linear.

  DON_RGB_4_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.don_rgb_4.` `DON_RGB_4_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1dd10>

  Don RGB 4 colourspace.

  DON_RGB_4_COLOURSPACE : RGB_Colourspace